@@ -8,29 +8,35 @@ extends 'API::Trello::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
+
+has camelize => (
+    is       => 'rw',
+    isa      => Int,
+    default  => 1,
+);
 
 has key => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has token => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 0,
 );
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Trello (Perl)',
 );
 
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 1,
 );
 
@@ -40,14 +46,16 @@ method AUTOLOAD () {
         unless Scalar::Util::blessed $self && $self->isa(__PACKAGE__);
 
     my @segments = @_;
+    my @results  = ();
 
-    # camelize the even parts
-    for (my $i = 0; $i < @segments; $i++) {
-        $segments[$i] =~ s/_([a-z])/\U$1/g if $i % 2 != 0;
+    my $camelize = $self->camelize;
+    while (my ($path, $param) = splice @segments, 0, 2) {
+        $path =~ s/([a-z])_([a-zA-Z])/$1\U$2/g if $camelize and defined $param;
+        push @results, $path, defined $param ? $param : ();
     }
 
     # return new resource instance dynamically
-    return $self->resource($method, @segments);
+    return $self->resource($method, @results);
 }
 
 method BUILD () {
@@ -139,7 +147,7 @@ API::Trello - Perl 5 API wrapper for Trello
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -320,6 +328,14 @@ represent and process the HTTP transaction.
 
 =head1 ATTRIBUTES
 
+=head2 camelize
+
+    $trello->camelize;
+    $trello->camelize(1);
+
+The camelize parameter determines whether HTTP request path parts will be
+automatically camelcased.
+
 =head2 identifier
 
     $trello->identifier;
@@ -403,9 +419,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $trello->action('head', %args);   # HEAD request
-    $trello->action('optons', %args); # OPTIONS request
-    $trello->action('patch', %args);  # PATCH request
+    $trello->action('head', %args);    # HEAD request
+    $trello->action('options', %args); # OPTIONS request
+    $trello->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
